Enum fork_tree::FinalizationResult[−][src]

pub enum FinalizationResult<V> {
    Changed(Option<V>),
    Unchanged,
}

Result of finalizing a node (that could be a part of the tree or not).

Variants

Changed(Option<V>)

The tree has changed, optionally return the value associated with the finalized node.

Unchanged

The tree has not changed.